==> jmb.core-0.8.3.tar.gz: jmb.core-0.8.3/jmb/core/management/commands/reset_password.py <==
"""

.. _reset-password:

reset_password
==============

it's a script whose goal is to be used in scripts (jmb-sync) when creating 
local db on developer's personal pc.

``jmb-sync`` resets the admin password so that browser can prefill password

::

  dj reset_password user pass


"""


from optparse import make_option

from django.contrib.auth import get_user_model
from django.core.management.base import BaseCommand, CommandError
from django.db import DEFAULT_DB_ALIAS


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('--database', action='store', dest='database',
                    default=DEFAULT_DB_ALIAS, help='Specifies the database to use. Default: "default".'),
    )
    help = "reset_password user pass: change a user's password for django.contrib.auth. Pass password in command line"

    requires_model_validation = False

    def handle(self, *args, **options):
        if args:
            username, password = args
        else:
            username = getpass.getuser()

        UserModel = get_user_model()

        try:
            u = UserModel._default_manager.using(options.get('database')).get(**{
                UserModel.USERNAME_FIELD: username
            })
        except UserModel.DoesNotExist:
            raise CommandError("user '%s' does not exist" % username)

        self.stdout.write("Changing password for user '%s'\n" % u)

        u.set_password(password)
        u.save()

        return "Password changed successfully for user '%s'" % u

==> jmb.core-0.8.7.tar.gz: jmb.core-0.8.7/jmb/core/management/commands/reset_password.py <==
"""

.. _reset-password:

reset_password
==============

it's a script whose goal is to be used in scripts (jmb-sync) when creating
local db on developer's personal pc.

``jmb-sync`` resets the admin password so that browser can prefill password

::

  dj reset_password user pass


"""
import getpass

from optparse import make_option

from django.contrib.auth import get_user_model
from django.core.management.base import BaseCommand, CommandError
from django.db import DEFAULT_DB_ALIAS


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('--database', action='store', dest='database',
                    default=DEFAULT_DB_ALIAS, help='Specifies the database to use. Default: "default".'),
    )
    help = "reset_password user pass: change a user's password for django.contrib.auth. Pass password in command line"

    #requires_model_validation = False
    requires_system_checks = False

    def handle(self, *args, **options):
        if args:
            username, password = args
        else:
            username = getpass.getuser()

        UserModel = get_user_model()

        try:
            u = UserModel._default_manager.using(options.get('database')).get(**{
                UserModel.USERNAME_FIELD: username
            })
        except UserModel.DoesNotExist:
            raise CommandError("user '%s' does not exist" % username)

        self.stdout.write("Changing password for user '%s'\n" % u)

        u.set_password(password)
        u.save()

        return "Password changed successfully for user '%s'" % u
